@@ -57,7 +57,7 @@ class CfnConnectionAlias(
         '''
         props = CfnConnectionAliasProps(connection_string=connection_string, tags=tags)
 
-        jsii.create(CfnConnectionAlias, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -325,7 +325,7 @@ class CfnWorkspace(
             workspace_properties=workspace_properties,
         )
 
-        jsii.create(CfnWorkspace, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
